"""Waterlight AI SDK — OpenAI-compatible client.

Usage:
    from waterlight import Waterlight

    client = Waterlight(api_key="wl-...")
    response = client.chat.completions.create(
        model="mist-1-turbo",
        messages=[{"role": "user", "content": "Hello"}],
    )
    print(response.choices[0].message.content)

Drop-in replacement for OpenAI:
    # Before
    from openai import OpenAI
    client = OpenAI()

    # After
    from waterlight import Waterlight
    client = Waterlight()
"""

from .client import Waterlight
from .errors import (
    WaterlightError,
    AuthenticationError,
    RateLimitError,
    InsufficientCreditsError,
    APIError,
)

__version__ = "0.2.1"

__all__ = [
    "Waterlight",
    "WaterlightError",
    "AuthenticationError",
    "RateLimitError",
    "InsufficientCreditsError",
    "APIError",
]
